% example Quokka3 settingsfile to fit a lifetime curve
% co-fits defect density of a Fei SRH defect and surface J0

% data from Fig. 5 in: B. Hammann et al., in IEEE Journal of Photovoltaics, vol. 13, no. 4, pp. 535-546, July 2023, doi: 10.1109/JPHOTOV.2023.3265859

% (c) 2023 AF Simulations GmbH

Syntax = 'generic';

Optim.Enable = 1;
Optim.Variable(1).Parameter = 'SkinFeature(1).Lumped.Electrical.NonContactedRecombination.J0';
Optim.Variable(1).Guess = 10 fA/cm2;
Optim.Variable(1).UpperBound = 100 fA/cm2;
Optim.Variable(1).LowerBound = 0.1 fA/cm2;
Optim.Variable(2).Parameter = 'Bulk.Electrical.Recombination.SRH(1).Nt';
Optim.Variable(2).Guess = 2e9;
Optim.Variable(2).UpperBound = 1e11;
Optim.Variable(2).LowerBound = 1e8;

Optim.Goal(1).Type = 'curve';
Optim.Goal(1).XResultName = '/Curves/deltanAvg';
Optim.Goal(1).YResultName = '/Curves/taueff';
Optim.Goal(1).Curve.Type = 'file';
Optim.Goal(1).Curve.File = 'tau_dn.csv'; % the measured lifetime curve
Optim.Goal(1).CurveWeightsType = 'equal'; % equal means the relative deviation to each datapoint matters, should be used for curves with large differences in absolute values
Optim.Goal(1).CurveRange.Enable = 1;
Optim.Goal(1).CurveRange.Xmin = 5e13; % exclude low injection points with too much noise
Optim.Goal(1).CurveRange.Xmax = 1.5e16; % exclude high injection points outside valid transient regime


Domain.DeviceType = 'semiconductor device';
Domain.Dimensions = 1;
Domain.Wz = 126 um; % half of actual 252um due to symmetry

Solver.SolutionType = 'sunsVoc-curve'; % sunsVoc-curve varies illumination intensity and simulates OC conditions, resulting in tauff(dn) datapoints - the lifetime curve
Solver.Electrical.MetalModelType = 'constant-potential';
Solver.Electrical.SkinJ0nieff.Type = 'user-T';
Solver.Electrical.SkinJ0nieff.T = 25 degC;

Optical.GenerationModelType = 'defined-generation';
Optical.DefinedGeneration.Type = 'uniform-Jgen'; % assumes that depth-wise carrier profile (and generation profile) doesn't matter, which is true for moderate to high lifetime samples
Optical.DefinedGeneration.UniformJgen = 40; % value doesn't matter, it is varied anyway in the suns-Voc simulation

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'p-type';
Bulk.BackgroundDoping.Resistivity = 1.09;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'sigma-Et-Nt'; % Fei defect properties from Istratov et al. Appl. Phys. A: Mater. Sci.
Bulk.Electrical.Recombination.SRH(1).sigman = 4e-14;
Bulk.Electrical.Recombination.SRH(1).sigmap = 6.8e-17;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = -0.16;
Bulk.Electrical.Recombination.SRH(1).Nt = 2e9;
Bulk.Electrical.Recombination.SRH(1).vth = 1.1e7;


SkinFeature(1).Name = 'front skin';
SkinFeature(1).Geometry.Plane = 'front';
SkinFeature(1).ElectricalModelType = 'lumped';
SkinFeature(1).Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
SkinFeature(1).Lumped.Electrical.NonContactedRecombination.J0 = 10 fA/cm2;

SkinFeature(2).Name = 'rear skin'; % perfect rear side equivalent to symmetry plane for OC conditions
SkinFeature(2).Geometry.Plane = 'rear';
SkinFeature(2).ElectricalModelType = 'lumped';

